Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(157)

Unified Diff: webrtc/api/videosourceproxy.h

Issue 1770003002: Renamed VideoSourceInterface to VideoTrackSourceInterface. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Rebased Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/api/videosourceproxy.h
diff --git a/webrtc/api/videosourceproxy.h b/webrtc/api/videosourceproxy.h
index e0f94dc881c77cdbcb538f6028a3e59d76352138..59adf890949c3981bfb4eb4e6af0f8ffc76962b4 100644
--- a/webrtc/api/videosourceproxy.h
+++ b/webrtc/api/videosourceproxy.h
@@ -16,22 +16,24 @@
namespace webrtc {
// VideoSourceProxy makes sure the real VideoSourceInterface implementation is
// destroyed on the signaling thread and marshals all method calls to the
// signaling thread.
-BEGIN_PROXY_MAP(VideoSource)
- PROXY_CONSTMETHOD0(SourceState, state)
- PROXY_CONSTMETHOD0(bool, remote)
- PROXY_METHOD0(cricket::VideoCapturer*, GetVideoCapturer)
- PROXY_METHOD0(void, Stop)
- PROXY_METHOD0(void, Restart)
- PROXY_METHOD2(void, AddOrUpdateSink,
- rtc::VideoSinkInterface<cricket::VideoFrame>*,
- const rtc::VideoSinkWants&)
- PROXY_METHOD1(void, RemoveSink, rtc::VideoSinkInterface<cricket::VideoFrame>*)
- PROXY_CONSTMETHOD0(const cricket::VideoOptions*, options)
- PROXY_METHOD1(void, RegisterObserver, ObserverInterface*)
- PROXY_METHOD1(void, UnregisterObserver, ObserverInterface*)
+BEGIN_PROXY_MAP(VideoTrackSource)
+PROXY_CONSTMETHOD0(SourceState, state)
+PROXY_CONSTMETHOD0(bool, remote)
+PROXY_METHOD0(cricket::VideoCapturer*, GetVideoCapturer)
+PROXY_METHOD0(void, Stop)
+PROXY_METHOD0(void, Restart)
+PROXY_METHOD2(void,
+ AddOrUpdateSink,
+ rtc::VideoSinkInterface<cricket::VideoFrame>*,
+ const rtc::VideoSinkWants&)
+PROXY_METHOD1(void, RemoveSink, rtc::VideoSinkInterface<cricket::VideoFrame>*)
+PROXY_CONSTMETHOD0(const cricket::VideoOptions*, options)
+PROXY_METHOD1(void, RegisterObserver, ObserverInterface*)
+PROXY_METHOD1(void, UnregisterObserver, ObserverInterface*)
END_PROXY()
} // namespace webrtc
@@ -16,22 +16,24 @@
namespace webrtc {
-// VideoSourceProxy makes sure the real VideoSourceInterface implementation is
+// VideoTrackSourceInterface makes sure the real VideoTrackSourceInterface
+// implementation is
// destroyed on the signaling thread and marshals all method calls to the
// signaling thread.

Powered by Google App Engine
This is Rietveld 408576698